VOCABULARY = {
    'adjectives': [
        'aristotelian',
        'arthurian',
        'bohemian',
        'brethren',
        'mosaic',
        'oceanic',
        'proctor',
        'terran',
        'tudor',
        'abroad',
        'absorbing',
        'abstract',
        'academic',
        'accelerated',
        'accented',
        'accountant',
        'acquainted',
        'acute',
        'addicting',
        'addictive',
        'adjustable',
        'admired',
        'adult',
        'adverse',
        'advised',
        'aerosol',
        'afraid',
        'aggravated',
        'aggressive',
        'agreeable',
        'alienate',
        'aligned',
        'alleged',
        'almond',
        'alright',
        'altruistic',
        'ambient',
        'ambivalent',
        'amiable',
        'amino',
        'amorphous',
        'amused',
        'anatomical',
        'ancestral',
        'angelic',
        'angrier',
        'answerable',
        'antiquarian',
        'antiretroviral',
        'appellate',
        'applicable',
        'apportioned',
        'approachable',
        'appropriated',
        'archer',
        'aroused',
        'arrested',
        'assertive',
        'assigned',
        'athletic',
        'atrocious',
        'attained',
        'authoritarian',
        'autobiographical',
        'avaricious',
        'avocado',
        'awake',
        'awsome',
        'backstage',
        'backwoods',
        'balding',
        'bandaged',
        'banded',
        'banned',
        'barreled',
        'battle',
        'beaten',
        'begotten',
        'beguiled',
        'bellied',
        'belted',
        'beneficent',
        'besieged',
        'betting',
        'biggest',
        'biochemical',
        'bipolar',
        'blackened',
        'blame',
        'blessed',
        'blindfolded',
        'bloat',
        'blocked',
        'blooded',
        'blushing',
        'boastful',
        'bolder',
        'bolstered',
        'bonnie',
        'bored',
        'boundary',
        'bounded',
        'bounding',
        'branched',
        'brawling',
        'brazen',
        'breeding',
        'bridged',
        'brimming',
        'brimstone',
        'broadest',
        'broiled',
        'broker',
        'bronze',
        'bruising',
        'buffy',
        'bullied',
        'bungling',
        'burial',
        'buttery',
        'candied',
        'canonical',
        'cantankerous',
        'cardinal',
        'carefree',
        'caretaker',
        'casual',
        'cathartic',
        'causal',
        'chapel',
        'characterized',
        'charcoal',
        'cheeky',
        'cherished',
        'chipotle',
        'chirping',
        'chivalrous',
        'circumstantial',
        'civic',
        'civil',
        'civilised',
        'clanking',
        'clapping',
        'claptrap',
        'classless',
        'cleansed',
        'cleric',
        'cloistered',
        'codified',
        'colloquial',
        'colour',
        'combat',
        'combined',
        'comely',
        'commissioned',
        'commonplace',
        'commuter',
        'commuting',
        'comparable',
        'complementary',
        'compromising',
        'conceding',
        'concentrated',
        'conceptual',
        'conditioned',
        'confederate',
        'confident',
        'confidential',
        'confining',
        'confuse',
        'congressional',
        'consequential',
        'conservative',
        'constituent',
        'contaminated',
        'contemporaneous',
        'contraceptive',
        'convertible',
        'convex',
        'cooked',
        'coronary',
        'corporatist',
        'correlated',
        'corroborated',
        'cosmic',
        'cover',
        'crash',
        'crypto',
        'culminate',
        'cushioned',
        'dandy',
        'dashing',
        'dazzled',
        'decreased',
        'decrepit',
        'dedicated',
        'defaced',
        'defective',
        'defenseless',
        'deluded',
        'deodorant',
        'departed',
        'depress',
        'designing',
        'despairing',
        'destitute',
        'detective',
        'determined',
        'devastating',
        'deviant',
        'devilish',
        'devoted',
        'diagonal',
        'dictated',
        'didactic',
        'differentiated',
        'diffused',
        'dirtier',
        'disabling',
        'disconnected',
        'discovered',
        'disdainful',
        'diseased',
        'disfigured',
        'disheartened',
        'disheveled',
        'disillusioned',
        'disparate',
        'dissident',
        'doable',
        'doctrinal',
        'doing',
        'dotted',
        'downbeat',
        'dozen',
        'draining',
        'draught',
        'dread',
        'dried',
        'dropped',
        'dulled',
        'duplicate',
        'eaten',
        'echoing',
        'economical',
        'elaborated',
        'elastic',
        'elective',
        'electoral',
        'elven',
        'embryo',
        'emerald',
        'emergency',
        'emissary',
        'emotional',
        'employed',
        'enamel',
        'encased',
        'encrusted',
        'endangered',
        'engraved',
        'engrossing',
        'enlarged',
        'enlisted',
        'enlivened',
        'ensconced',
        'entangled',
        'enthralling',
        'entire',
        'envious',
        'eradicated',
        'eroded',
        'esoteric',
        'essential',
        'evaporated',
        'evergreen',
        'everlasting',
        'exacting',
        'exasperated',
        'excess',
        'exciting',
        'executable',
        'existent',
        'exonerated',
        'exorbitant',
        'exponential',
        'export',
        'extraordinary',
        'exultant',
        'exulting',
        'facsimile',
        'fading',
        'fainter',
        'fallacious',
        'faltering',
        'famous',
        'fancier',
        'fated',
        'favourable',
        'fearless',
        'feathered',
        'fellow',
        'fermented',
        'ferocious',
        'fiddling',
        'filling',
        'firmer',
        'fitted',
        'flammable',
        'flawed',
        'fledgling',
        'fleshy',
        'flexible',
        'flickering',
        'floral',
        'flowering',
        'flowing',
        'foggy',
        'folic',
        'foolhardy',
        'foolish',
        'footy',
        'forehand',
        'forked',
        'formative',
        'formulaic',
        'fractional',
        'fragrant',
        'fraudulent',
        'freakish',
        'freckled',
        'freelance',
        'freight',
        'fresh',
        'fretted',
        'frugal',
        'fulfilling',
        'fuming',
        'funded',
        'funny',
        'garbled',
        'gathered',
        'geologic',
        'geometric',
        'gibberish',
        'gilded',
        'ginger',
        'glare',
        'glaring',
        'gleaming',
        'glorified',
        'glorious',
        'goalless',
        'goody',
        'grammatical',
        'grande',
        'grateful',
        'gratuitous',
        'graven',
        'greener',
        'grinding',
        'grizzly',
        'groaning',
        'grudging',
        'guaranteed',
        'gusty',
        'handheld',
        'harlot',
        'healing',
        'healthier',
        'healthiest',
        'heart',
        'heathen',
        'hedonistic',
        'heralded',
        'herbal',
        'hissy',
        'hitless',
        'holiness',
        'homesick',
        'honorable',
        'hooded',
        'hopeless',
        'horrendous',
        'horrible',
        'huddled',
        'human',
        'humbling',
        'humid',
        'humiliating',
        'hypnotized',
        'idealistic',
        'idiosyncratic',
        'ignited',
        'illustrated',
        'illustrative',
        'imitated',
        'immense',
        'immersive',
        'immigrant',
        'immoral',
        'impassive',
        'impressionable',
        'improbable',
        'impulsive',
        'inattentive',
        'inbound',
        'inbounds',
        'incalculable',
        'incomprehensible',
        'indefatigable',
        'indigo',
        'indiscriminate',
        'indomitable',
        'inert',
        'inflate',
        'inform',
        'inheriting',
        'injured',
        'injurious',
        'inking',
        'inoffensive',
        'insane',
        'insensible',
        'insidious',
        'insincere',
        'insistent',
        'insolent',
        'insufferable',
        'intemperate',
        'interdependent',
        'interesting',
        'interfering',
        'intern',
        'interpreted',
        'intersecting',
        'intolerable',
        'intolerant',
        'intuitive',
        'irresolute',
        'irritate',
        'jealous',
        'jerking',
        'joining',
        'joint',
        'journalistic',
        'joyful',
        'keyed',
        'knowing',
        'lacklustre',
        'laden',
        'lagging',
        'lamented',
        'laughable',
        'layered',
        'leather',
        'leathern',
        'leery',
        'legible',
        'leisure',
        'lessening',
        'liberating',
        'lifted',
        'lightest',
        'limitless',
        'listening',
        'literary',
        'liver',
        'livid',
        'lobster',
        'locked',
        'loudest',
        'loveliest',
        'lowering',
        'lucid',
        'luckless',
        'lusty',
        'luxurious',
        'magazine',
        'maniac',
        'manmade',
        'maroon',
        'mastered',
        'mated',
        'material',
        'materialistic',
        'meaningful',
        'measuring',
        'mediaeval',
        'medical',
        'meditated',
        'medley',
        'melodic',
        'memorable',
        'memorial',
        'metabolic',
        'metallic',
        'metallurgical',
        'metering',
        'midair',
        'midterm',
        'midway',
        'mighty',
        'migrating',
        'minor',
        'mirrored',
        'misguided',
        'misshapen',
        'mitigated',
        'mixed',
        'modernized',
        'molecular',
        'monarch',
        'monastic',
        'morbid',
        'motley',
        'motorized',
        'mounted',
        'multidisciplinary',
        'muscled',
        'muscular',
        'muted',
        'mysterious',
        'mythic',
        'natural',
        'nauseous',
        'negative',
        'networked',
        'neurological',
        'neutered',
        'newest',
        'night',
        'nitrous',
        'noncommercial',
        'nonsense',
        'north',
        'nuanced',
        'occurring',
        'offensive',
        'oldest',
        'oncoming',
        'onstage',
        'onward',
        'opaque',
        'operating',
        'opportunist',
        'opposing',
        'ordinate',
        'outdone',
        'outlaw',
        'outsized',
        'overboard',
        'overheated',
        'oversize',
        'overworked',
        'oyster',
        'paced',
        'panting',
        'paralyzed',
        'paramount',
        'parental',
        'parted',
        'partisan',
        'passive',
        'pastel',
        'patriot',
        'peacekeeping',
        'pedestrian',
        'peevish',
        'penal',
        'penned',
        'pensive',
        'perceptual',
        'perky',
        'permissible',
        'pernicious',
        'perpetuate',
        'perplexed',
        'pervasive',
        'petrochemical',
        'philosophical',
        'picturesque',
        'pillaged',
        'piped',
        'piquant',
        'pitching',
        'plausible',
        'pliable',
        'plumb',
        'politician',
        'polygamous',
        'poorest',
        'portmanteau',
        'posed',
        'positive',
        'possible',
        'postpartum',
        'prank',
        'precocious',
        'predicted',
        'premium',
        'preparatory',
        'prerequisite',
        'prescient',
        'preserved',
        'presidential',
        'pressed',
        'pressurized',
        'presumed',
        'prewar',
        'priced',
        'pricier',
        'primal',
        'primer',
        'primetime',
        'printed',
        'private',
        'problem',
        'procedural',
        'process',
        'prodigious',
        'professional',
        'programmed',
        'progressive',
        'prolific',
        'promising',
        'promulgated',
        'pronged',
        'proportionate',
        'protracted',
        'pulled',
        'pulsed',
        'purgatory',
        'quick',
        'raunchy',
        'razed',
        'reactive',
        'readable',
        'realizing',
        'recognised',
        'recovering',
        'recurrent',
        'recycled',
        'redeemable',
        'reflecting',
        'regal',
        'registering',
        'reliable',
        'reminiscent',
        'remorseless',
        'removable',
        'renewable',
        'repeating',
        'repellent',
        'reserve',
        'resigned',
        'respectful',
        'rested',
        'restrict',
        'resultant',
        'retaliatory',
        'retiring',
        'revelatory',
        'reverend',
        'reversing',
        'revolving',
        'ridiculous',
        'ringed',
        'risque',
        'robust',
        'roomful',
        'rotating',
        'roused',
        'rubber',
        'running',
        'runtime',
        'rustling',
        'safest',
        'salient',
        'sanctioned',
        'saute',
        'saved',
        'scandalized',
        'scarlet',
        'scattering',
        'sceptical',
        'scheming',
        'scoundrel',
        'scratched',
        'scratchy',
        'scrolled',
        'seated',
        'segregated',
        'semiautomatic',
        'senior',
        'sensed',
        'sentient',
        'sexier',
        'shadowy',
        'shaken',
        'shaker',
        'shameless',
        'shaped',
        'shiny',
        'shipped',
        'shivering',
        'shoestring',
        'short',
        'signed',
        'simplest',
        'simplistic',
        'sizable',
        'skeleton',
        'skinny',
        'skirting',
        'skyrocketed',
        'slamming',
        'slanting',
        'slapstick',
        'sleek',
        'sleepless',
        'sleepy',
        'slender',
        'slimmer',
        'smacking',
        'smokeless',
        'smothered',
        'smouldering',
        'snuff',
        'socialized',
        'sometime',
        'sought',
        'spanking',
        'sparing',
        'spattered',
        'specialized',
        'specific',
        'speedy',
        'spherical',
        'spiky',
        'spineless',
        'sprung',
        'squint',
        'stainless',
        'standing',
        'starlight',
        'startled',
        'stately',
        'statewide',
        'stereoscopic',
        'sticky',
        'stimulant',
        'stinky',
        'stoked',
        'stolen',
        'storied',
        'strained',
        'strapping',
        'strengthened',
        'stubborn',
        'stylized',
        'suave',
        'subjective',
        'subjugated',
        'subordinate',
        'succeeding',
        'suffering',
        'summary',
        'sunset',
        'sunshine',
        'supernatural',
        'supervisory',
        'surrogate',
        'suspended',
        'suspenseful',
        'swarthy',
        'sweating',
        'sweeping',
        'swinging',
        'swooning',
        'sympathize',
        'synchronized',
        'synonymous',
        'synthetic',
        'tailed',
        'tallest',
        'tangible',
        'tanked',
        'tarry',
        'technical',
        'tectonic',
        'telepathic',
        'tenderest',
        'territorial',
        'testimonial',
        'theistic',
        'thicker',
        'threatening',
        'timed',
        'timely',
        'timid',
        'torrent',
        'totalled',
        'tougher',
        'traditional',
        'transformed',
        'trapped',
        'traveled',
        'traverse',
        'treated',
        'trial',
        'trunk',
        'trusting',
        'trying',
        'twisted',
        'tyrannical',
        'unaided',
        'unassisted',
        'unassuming',
        'unattractive',
        'uncapped',
        'uncomfortable',
        'uncontrolled',
        'uncooked',
        'uncooperative',
        'underground',
        'undersea',
        'undisturbed',
        'unearthly',
        'uneasy',
        'unequal',
        'unfazed',
        'unfinished',
        'unforeseen',
        'unforgivable',
        'unidentified',
        'unimaginative',
        'uninspired',
        'unintended',
        'uninvited',
        'universal',
        'unmasked',
        'unorthodox',
        'unparalleled',
        'unpleasant',
        'unprincipled',
        'unread',
        'unreasonable',
        'unregulated',
        'unreliable',
        'unremitting',
        'unsafe',
        'unsanitary',
        'unsealed',
        'unsuccessful',
        'unsupervised',
        'untimely',
        'unwary',
        'unwrapped',
        'uppity',
        'upstart',
        'useless',
        'utter',
        'valiant',
        'valid',
        'valued',
        'vanilla',
        'vaulting',
        'vaunted',
        'veering',
        'vegetative',
        'vented',
        'verbal',
        'verifying',
        'veritable',
        'versed',
        'vinyl',
        'virgin',
        'visceral',
        'visual',
        'voluptuous',
        'wanton',
        'warlike',
        'washed',
        'waterproof',
        'waved',
        'weakest',
        'wetting',
        'wheeled',
        'whirlwind',
        'widen',
        'widening',
        'willful',
        'willing',
        'winnable',
        'winningest',
        'wireless',
        'wistful',
        'woeful',
        'wooded',
        'woodland',
        'wordless',
        'workable',
        'worldly',
        'worldwide',
        'worsted',
        'worthless',
    ],
    'nouns': [
        'armour',
        'barrymore',
        'cabot',
        'catholicism',
        'chihuahua',
        'christianity',
        'easter',
        'frenchman',
        'lowry',
        'mayer',
        'orientalism',
        'pharaoh',
        'pueblo',
        'pullman',
        'rodeo',
        'saturday',
        'sister',
        'snead',
        'syrah',
        'tuesday',
        'woodward',
        'abbey',
        'absence',
        'absorption',
        'abstinence',
        'absurdity',
        'abundance',
        'acceptance',
        'accessibility',
        'accommodation',
        'accomplice',
        'accountability',
        'accounting',
        'accreditation',
        'accuracy',
        'acquiescence',
        'acreage',
        'actress',
        'actuality',
        'adage',
        'adaptation',
        'adherence',
        'adjustment',
        'adoption',
        'adultery',
        'advancement',
        'advert',
        'advertisement',
        'advertising',
        'advice',
        'aesthetics',
        'affinity',
        'aggression',
        'agriculture',
        'aircraft',
        'airtime',
        'allegation',
        'allegiance',
        'allegory',
        'allergy',
        'allies',
        'alligator',
        'allocation',
        'allotment',
        'altercation',
        'ambulance',
        'ammonia',
        'anatomy',
        'anemia',
        'ankle',
        'announcement',
        'annoyance',
        'annuity',
        'anomaly',
        'anthropology',
        'anxiety',
        'apartheid',
        'apologise',
        'apostle',
        'apparatus',
        'appeasement',
        'appellation',
        'appendix',
        'applause',
        'appointment',
        'appraisal',
        'archery',
        'archipelago',
        'architecture',
        'ardor',
        'arrears',
        'arrow',
        'artisan',
        'artistry',
        'ascent',
        'assembly',
        'assignment',
        'association',
        'asthma',
        'atheism',
        'attacker',
        'attraction',
        'attractiveness',
        'auspices',
        'authority',
        'avarice',
        'aversion',
        'aviation',
        'babbling',
        'backlash',
        'baker',
        'ballet',
        'balls',
        'banjo',
        'baron',
        'barrier',
        'barrister',
        'bases',
        'basin',
        'basis',
        'battery',
        'battling',
        'bedtime',
        'beginner',
        'begun',
        'bending',
        'bicycle',
        'billing',
        'bingo',
        'biography',
        'biology',
        'birthplace',
        'blackberry',
        'blather',
        'blossom',
        'boardroom',
        'boasting',
        'bodyguard',
        'boldness',
        'bomber',
        'bondage',
        'bonding',
        'bones',
        'bonus',
        'bookmark',
        'boomer',
        'booty',
        'bounds',
        'bowling',
        'brainstorming',
        'breadth',
        'breaker',
        'brewer',
        'brightness',
        'broccoli',
        'broth',
        'brotherhood',
        'browsing',
        'brunch',
        'brunt',
        'building',
        'bullion',
        'bureaucracy',
        'burglary',
        'buyout',
        'cabal',
        'cabbage',
        'calamity',
        'campaign',
        'canonization',
        'captaincy',
        'carcass',
        'carrier',
        'cartridge',
        'cassette',
        'catfish',
        'caught',
        'celebrity',
        'cemetery',
        'certainty',
        'certification',
        'charade',
        'chasm',
        'cheerleader',
        'cheesecake',
        'chemotherapy',
        'chili',
        'china',
        'chivalry',
        'cholera',
        'cilantro',
        'circus',
        'civilisation',
        'civility',
        'clearance',
        'clearing',
        'clerk',
        'climber',
        'closeness',
        'clothing',
        'clutches',
        'coaster',
        'coconut',
        'coding',
        'collaborator',
        'colleague',
        'college',
        'collision',
        'colors',
        'combustion',
        'comedian',
        'comer',
        'commander',
        'commemoration',
        'commenter',
        'commissioner',
        'commune',
        'competition',
        'completeness',
        'complexity',
        'computing',
        'comrade',
        'concur',
        'condominium',
        'conduit',
        'confidant',
        'configuration',
        'confiscation',
        'conflagration',
        'conflict',
        'consist',
        'consistency',
        'consolidation',
        'conspiracy',
        'constable',
        'consul',
        'consultancy',
        'contentment',
        'contents',
        'contractor',
        'conversation',
        'cornerstone',
        'corpus',
        'correlation',
        'councilman',
        'counselor',
        'countdown',
        'countryman',
        'coverage',
        'covering',
        'coyote',
        'cracker',
        'creator',
        'criminality',
        'crocodile',
        'cropping',
        'crossover',
        'crossroads',
        'culprit',
        'cumin',
        'curator',
        'curfew',
        'cursor',
        'custard',
        'cutter',
        'cyclist',
        'cyclone',
        'cylinder',
        'cynicism',
        'daddy',
        'damsel',
        'darkness',
        'dawning',
        'daybreak',
        'dealing',
        'dedication',
        'deduction',
        'defection',
        'deference',
        'deficiency',
        'definition',
        'deflation',
        'degeneration',
        'delegation',
        'delicacy',
        'delirium',
        'deliverance',
        'demeanor',
        'demon',
        'demonstration',
        'denomination',
        'dentist',
        'departure',
        'depletion',
        'depression',
        'designation',
        'despotism',
        'detention',
        'developer',
        'devolution',
        'dexterity',
        'diagnosis',
        'dialect',
        'differentiation',
        'digger',
        'digress',
        'dioxide',
        'diploma',
        'disability',
        'disarmament',
        'discord',
        'discovery',
        'dishonesty',
        'dismissal',
        'disobedience',
        'dispatcher',
        'disservice',
        'distribution',
        'distributor',
        'diver',
        'diversity',
        'docking',
        'dollar',
        'dominance',
        'domination',
        'dominion',
        'donkey',
        'doorstep',
        'doorway',
        'dossier',
        'downside',
        'drafting',
        'drank',
        'drilling',
        'driver',
        'drumming',
        'drunkenness',
        'duchess',
        'ducking',
        'dugout',
        'dumps',
        'dwelling',
        'dynamics',
        'eagerness',
        'earnestness',
        'earnings',
        'eater',
        'editor',
        'effectiveness',
        'electricity',
        'elements',
        'eloquence',
        'emancipation',
        'embodiment',
        'embroidery',
        'emperor',
        'employment',
        'encampment',
        'enclosure',
        'encouragement',
        'endangerment',
        'enlightenment',
        'enthusiasm',
        'environment',
        'environs',
        'envoy',
        'epilepsy',
        'equation',
        'equator',
        'error',
        'espionage',
        'estimation',
        'evacuation',
        'exaggeration',
        'examination',
        'exclamation',
        'expediency',
        'exploitation',
        'extinction',
        'eyewitness',
        'falls',
        'fascism',
        'fastball',
        'feces',
        'feedback',
        'ferocity',
        'fertilization',
        'fetish',
        'finale',
        'firing',
        'fixing',
        'flashing',
        'flask',
        'flora',
        'fluke',
        'folklore',
        'follower',
        'foothold',
        'footing',
        'forefinger',
        'forefront',
        'forgiveness',
        'formality',
        'formation',
        'formula',
        'foyer',
        'fragmentation',
        'framework',
        'fraud',
        'freestyle',
        'frequency',
        'friendliness',
        'fries',
        'frigate',
        'fulfillment',
        'function',
        'functionality',
        'fundraiser',
        'fusion',
        'futility',
        'gallantry',
        'gallery',
        'genesis',
        'genitals',
        'girlfriend',
        'glamour',
        'glitter',
        'glucose',
        'google',
        'grandeur',
        'grappling',
        'greens',
        'gridlock',
        'grocer',
        'groundwork',
        'grouping',
        'gunman',
        'gusto',
        'habitation',
        'hacker',
        'hallway',
        'hamburger',
        'hammock',
        'handling',
        'hands',
        'handshake',
        'happiness',
        'hardship',
        'headcount',
        'header',
        'headquarters',
        'heads',
        'headset',
        'hearth',
        'hearts',
        'heath',
        'hegemony',
        'height',
        'hello',
        'helper',
        'helping',
        'helplessness',
        'hierarchy',
        'hoarding',
        'hockey',
        'homeland',
        'homer',
        'honesty',
        'horror',
        'horseman',
        'hostility',
        'housing',
        'humility',
        'hurricane',
        'iceberg',
        'ignition',
        'illness',
        'illustration',
        'illustrator',
        'immunity',
        'immunization',
        'imperialism',
        'imprisonment',
        'inaccuracy',
        'inaction',
        'inactivity',
        'inauguration',
        'indecency',
        'indicator',
        'inevitability',
        'infamy',
        'infiltration',
        'influx',
        'iniquity',
        'innocence',
        'innovation',
        'insanity',
        'inspiration',
        'instruction',
        'instructor',
        'insurer',
        'interact',
        'intercession',
        'intercourse',
        'intermission',
        'interpretation',
        'intersection',
        'interval',
        'intolerance',
        'intruder',
        'invasion',
        'investment',
        'involvement',
        'irrigation',
        'iteration',
        'jenny',
        'jogging',
        'jones',
        'joseph',
        'juggernaut',
        'juncture',
        'jurisprudence',
        'juror',
        'kangaroo',
        'kingdom',
        'knocking',
        'laborer',
        'larceny',
        'laurels',
        'layout',
        'leadership',
        'leasing',
        'legislation',
        'leopard',
        'liberation',
        'licence',
        'lifeblood',
        'lifeline',
        'ligament',
        'lighting',
        'likeness',
        'lineage',
        'liner',
        'lineup',
        'liquidation',
        'listener',
        'literature',
        'litigation',
        'litre',
        'loathing',
        'locality',
        'lodging',
        'logic',
        'longevity',
        'lookout',
        'lordship',
        'lustre',
        'maam',
        'machinery',
        'madness',
        'magnificence',
        'mahogany',
        'mailing',
        'mainframe',
        'maintenance',
        'majority',
        'manga',
        'mango',
        'manifesto',
        'mantra',
        'manufacturer',
        'maple',
        'martin',
        'martyrdom',
        'mathematician',
        'matrix',
        'matron',
        'mayhem',
        'mayor',
        'means',
        'meantime',
        'measurement',
        'mechanics',
        'mediator',
        'medics',
        'melodrama',
        'memory',
        'mentality',
        'metaphysics',
        'method',
        'metre',
        'miner',
        'mirth',
        'misconception',
        'misery',
        'mishap',
        'misunderstanding',
        'mobility',
        'molasses',
        'momentum',
        'monarchy',
        'monument',
        'morale',
        'mortality',
        'motto',
        'mouthful',
        'mouthpiece',
        'mover',
        'movie',
        'mowing',
        'murderer',
        'musician',
        'mutation',
        'mythology',
        'narration',
        'narrator',
        'nationality',
        'negligence',
        'neighborhood',
        'neighbour',
        'nervousness',
        'networking',
        'nexus',
        'nightmare',
        'nobility',
        'nobody',
        'noodle',
        'normalcy',
        'notification',
        'nourishment',
        'novella',
        'nucleus',
        'nuisance',
        'nursery',
        'nutrition',
        'nylon',
        'oasis',
        'obscenity',
        'obscurity',
        'observer',
        'offense',
        'onslaught',
        'operation',
        'opportunity',
        'opposition',
        'oracle',
        'orchestra',
        'organisation',
        'organizer',
        'orientation',
        'originality',
        'ounce',
        'outage',
        'outcome',
        'outdoors',
        'outfield',
        'outing',
        'outpost',
        'outset',
        'overseer',
        'owner',
        'oxygen',
        'pairing',
        'panther',
        'paradox',
        'parliament',
        'parsley',
        'parson',
        'passenger',
        'pasta',
        'patchwork',
        'pathos',
        'patriotism',
        'pendulum',
        'penguin',
        'permission',
        'persona',
        'perusal',
        'pessimism',
        'peter',
        'philosopher',
        'phosphorus',
        'phrasing',
        'physique',
        'piles',
        'plateau',
        'playing',
        'plaza',
        'plethora',
        'plurality',
        'pneumonia',
        'pointer',
        'poker',
        'policeman',
        'polling',
        'poster',
        'posterity',
        'posting',
        'postponement',
        'potassium',
        'pottery',
        'poultry',
        'pounding',
        'pragmatism',
        'precedence',
        'precinct',
        'preoccupation',
        'pretense',
        'priesthood',
        'prisoner',
        'privacy',
        'probation',
        'proceeding',
        'proceedings',
        'processing',
        'processor',
        'progression',
        'projection',
        'prominence',
        'propensity',
        'prophecy',
        'prorogation',
        'prospectus',
        'protein',
        'prototype',
        'providence',
        'provider',
        'provocation',
        'proximity',
        'puberty',
        'publicist',
        'publicity',
        'publisher',
        'pundit',
        'putting',
        'quantity',
        'quart',
        'quilting',
        'quorum',
        'racism',
        'radiance',
        'ralph',
        'rancher',
        'ranger',
        'rapidity',
        'rapport',
        'ratification',
        'rationality',
        'reaction',
        'reader',
        'reassurance',
        'rebirth',
        'receptor',
        'recipe',
        'recognition',
        'recourse',
        'recreation',
        'rector',
        'recurrence',
        'redemption',
        'redistribution',
        'redundancy',
        'refinery',
        'reformer',
        'refrigerator',
        'regularity',
        'regulator',
        'reinforcement',
        'reins',
        'reinstatement',
        'relativism',
        'relaxation',
        'rendition',
        'repayment',
        'repentance',
        'repertoire',
        'repository',
        'republic',
        'reputation',
        'resentment',
        'residency',
        'resignation',
        'restaurant',
        'resurgence',
        'retailer',
        'retention',
        'retirement',
        'reviewer',
        'riches',
        'righteousness',
        'roadblock',
        'robber',
        'rocks',
        'rubbing',
        'runoff',
        'saloon',
        'salvation',
        'sarcasm',
        'saucer',
        'savior',
        'scarcity',
        'scenario',
        'scenery',
        'schism',
        'scholarship',
        'schoolboy',
        'schooner',
        'scissors',
        'scolding',
        'scooter',
        'scouring',
        'scrimmage',
        'scrum',
        'seating',
        'sediment',
        'seduction',
        'seeder',
        'seizure',
        'semicolon',
        'semiconductor',
        'semifinal',
        'senator',
        'sending',
        'serenity',
        'seriousness',
        'servitude',
        'sesame',
        'setup',
        'sewing',
        'sharpness',
        'shaving',
        'shoplifting',
        'shopping',
        'siding',
        'simplicity',
        'simulation',
        'sinking',
        'skate',
        'sloth',
        'slugger',
        'snack',
        'snail',
        'snapshot',
        'snark',
        'soccer',
        'solemnity',
        'solicitation',
        'solitude',
        'somewhere',
        'sophistication',
        'sorcery',
        'souvenir',
        'spaghetti',
        'specification',
        'specimen',
        'specs',
        'spectacle',
        'spectre',
        'speculation',
        'sperm',
        'spoiler',
        'squad',
        'squid',
        'staging',
        'stagnation',
        'staircase',
        'stairway',
        'stamina',
        'standpoint',
        'standstill',
        'stanza',
        'statement',
        'stillness',
        'stimulus',
        'stocks',
        'stole',
        'stoppage',
        'storey',
        'storyteller',
        'stylus',
        'subcommittee',
        'subscription',
        'subsidy',
        'suburb',
        'success',
        'sufferer',
        'supposition',
        'suspension',
        'sweater',
        'sweepstakes',
        'swimmer',
        'syndrome',
        'synopsis',
        'syntax',
        'system',
        'tablespoon',
        'taker',
        'tavern',
        'technology',
        'telephony',
        'template',
        'tempo',
        'tendency',
        'tendon',
        'terrier',
        'terror',
        'terry',
        'theater',
        'theology',
        'therapy',
        'thicket',
        'thoroughfare',
        'threshold',
        'thriller',
        'thunderstorm',
        'ticker',
        'tiger',
        'tights',
        'tossing',
        'touchdown',
        'tourist',
        'tourney',
        'toxicity',
        'tracing',
        'tractor',
        'translation',
        'transmission',
        'transmitter',
        'trauma',
        'traveler',
        'treadmill',
        'trilogy',
        'trout',
        'tuning',
        'twenties',
        'tycoon',
        'tyrant',
        'ultimatum',
        'underdog',
        'underwear',
        'unhappiness',
        'unification',
        'university',
        'uprising',
        'vaccination',
        'validity',
        'vampire',
        'vanguard',
        'variation',
        'vegetation',
        'verification',
        'viability',
        'vicinity',
        'victory',
        'viewpoint',
        'villa',
        'vindication',
        'violation',
        'vista',
        'vocalist',
        'vogue',
        'volcano',
        'voltage',
        'vomiting',
        'vulnerability',
        'waistcoat',
        'waitress',
        'wardrobe',
        'warmth',
        'watchdog',
        'wealth',
        'weariness',
        'whereabouts',
        'whisky',
        'whiteness',
        'widget',
        'width',
        'windfall',
        'wiring',
        'witchcraft',
        'withholding',
        'womanhood',
        'words',
        'workman',
        'youngster',
    ],
}
